Documentation
¶
Index ¶
- Variables
- func Append(ctx *r.Context) *r.Node
- func Area(ctx *r.Context) *r.Node
- func Button() *r.Node
- func Checkbox(ctx *r.Context) *r.Node
- func Clock(ctx *r.Context) *r.Node
- func CollatePage(ctx *r.Context) *r.Node
- func Counter(ctx *r.Context) *r.Node
- func Date(ctx *r.Context) *r.Node
- func FormPage(ctx *r.Context) *r.Node
- func HandleAppendEnd(ctx *r.Context) string
- func HandleAppendStart(ctx *r.Context) string
- func HandleClockStart(ctx *r.Context) string
- func HandleFormSubmit(ctx *r.Context) string
- func HandleHelloCrash(ctx *r.Context) string
- func HandleHelloDelay(ctx *r.Context) string
- func HandleHelloError(ctx *r.Context) string
- func HandleHelloOk(ctx *r.Context) string
- func HandleLoginSubmit(ctx *r.Context) string
- func HandleRedirectButton(ctx *r.Context) string
- func HandleRedirectDashboard(ctx *r.Context) string
- func HandleRedirectInvoices(ctx *r.Context) string
- func HandleRoutesProduct(ctx *r.Context) string
- func HandleRoutesSearch(ctx *r.Context) string
- func HandleRoutesUser(ctx *r.Context) string
- func HandleRoutesUserPost(ctx *r.Context) string
- func HandleSelectChange(ctx *r.Context) string
- func HandleSharedReset(ctx *r.Context) string
- func HandleSharedSubmit(ctx *r.Context) string
- func Hello(ctx *r.Context) *r.Node
- func Icons(ctx *r.Context) *r.Node
- func LoginPage(ctx *r.Context) *r.Node
- func NavTo(url string, content func() *r.Node) r.ActionHandler
- func NewData() *r.DataTable[Product]
- func Number(ctx *r.Context) *r.Node
- func Others(ctx *r.Context) *r.Node
- func Password(ctx *r.Context) *r.Node
- func Radio(ctx *r.Context) *r.Node
- func RegisterAppend(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterArea(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterButton(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterCheckbox(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterClock(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterCollate(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterCounter(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterDate(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterForm(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterHello(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterIcons(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterLogin(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterNumber(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterOthers(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterPassword(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterRadio(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterReloadRedirect(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterRoutes(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterSelect(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterShared(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterShowcase(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterSkeleton(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterTable(app *r.App, layout func(*r.Node) *r.Node)
- func RegisterText(app *r.App, layout func(*r.Node) *r.Node)
- func ReloadRedirect(ctx *r.Context) *r.Node
- func RoutesExample(ctx *r.Context) *r.Node
- func SelectPage(ctx *r.Context) *r.Node
- func Shared(ctx *r.Context) *r.Node
- func Showcase(ctx *r.Context) *r.Node
- func Skeleton(ctx *r.Context) *r.Node
- func TablePage(ctx *r.Context) *r.Node
- func Text(ctx *r.Context) *r.Node
- type CollateDataRequest
- type Employee
- type FormData
- type Product
- type TableDataRequest
Constants ¶
This section is empty.
Variables ¶
var ContentID = r.Target()
ContentID is the shared target ID for the main content area.
Functions ¶
func HandleAppendEnd ¶
func HandleAppendStart ¶
func HandleClockStart ¶
HandleClockStart is a WS action that spawns a goroutine to push live clock updates every second over the caller's WebSocket connection.
func HandleFormSubmit ¶
func HandleHelloCrash ¶
func HandleHelloDelay ¶
func HandleHelloError ¶
func HandleHelloOk ¶
func HandleLoginSubmit ¶
func HandleRedirectButton ¶
func HandleRedirectDashboard ¶
func HandleRedirectInvoices ¶
func HandleRoutesProduct ¶
func HandleRoutesSearch ¶
func HandleRoutesUser ¶
func HandleRoutesUserPost ¶
func HandleSelectChange ¶
func HandleSharedReset ¶
func HandleSharedSubmit ¶
Types ¶
type CollateDataRequest ¶
type Employee ¶
type Employee struct {
ID int
Name string
Department string
Salary float64
HireDate string
Active bool
Role string
}
Employee is the sample type for the Collate demo.
type Product ¶
type Product struct {
ID int
Name string
Price float64
Stock int
CreatedAt string // Date column for filter demo
Category string // Select filter demo
Status string // Status badge demo
}
Product is the sample type for the DataTable demo.
type TableDataRequest ¶
type TableDataRequest struct {
Operation string `json:"operation"`
Search string `json:"search"`
Page int `json:"page"`
PageSize int `json:"pageSize"`
Sort int `json:"sort"`
Dir string `json:"dir"`
Col int `json:"col"`
Type string `json:"type"`
Op string `json:"op"`
Val string `json:"val"`
Vals []string `json:"vals"`
From string `json:"from"`
To string `json:"to"`
}
TableDataRequest represents the incoming data from table operations
Click to show internal directories.
Click to hide internal directories.